.ll 120
.nr LL 120
.TH XTPANEL l "24 September 1992"
.SH NAME
xtpanel \- build an interactive program, from the command line
or using a simple scripting language
.SH SYNOPSIS
\fBxtpanel\fP [-help] [-tty] [-cpp] [cpp_args] [-file script_file] [-message] 
[-button] [-slider] [-scroolbar] [-dialog] [-choice] [-list] [-menubutton] 
[-var] [-quit] < script_file

.SH DESCRIPTION

\fIxtpanel\fP provides a quick and easy way of producing a panel
containing interactive objects such as buttons, sliders, and text
fields, either from the command line or from an xtpanel script file.
Each panel object maintains a string representation of its value. When
the object is modified it updates its value and it can also perform one
or more actions such as printing its value or calling a system command. 
Objects can make use of the values of other objects in constructing their
actions and they can set the values of other objects as the result of
an action. The result is an interactive X windows program, without the
need for conventional programming.

.PP

Three utilities are provided with xtpanel. The first is a script
generator. This is a collection af xtpanel scripts that can be used to
generate, examine and test xtpanel script files. It is invoked using
the command \fIxtpanel-generator\fP.  The second utility is a
collection of example scripts and a master script that can be use to
view and run the examples. It is invoked using the command
\fIxtpanel-examples\fP.  A particularly powerful demo is the "lister"
script example, which is a tool for maneuvering through a Unix
filesystem and viewing files at any level. The third is a set of
xtpanel scripts that present information about xtpanel, mostly taken
from this manual page, in an interactive, menu-driven form. This
is invoked by doing \fIxtpanel -help\fP.

.SH OBJECT TYPES
xtpanel supports the following objects: 
 
.IP message 10
Displays a single line of text.

.IP text 10
Displays multiple lines of text in a scrollable area.

.IP button 10
A single button.

.IP dialog 10
Provides an editable text field, with a label and an OK button.

.IP scrollbar 10
Allows the user to choose a value from a range of integer
or floating point values. 

.IP slider 10
A slider is a composite object containing a label a scrollbar
and an OK button.

.IP choice 10
A group of buttons, only one of which may be selected at a time.

.IP menubutton 10
A button with a menu attached.

.IP list 10
A list of character strings, only one of which may be selected at a time.

.IP var 10
A variable that has no screen representation but stores a value.

.PP
In addition there are several objects that group
other objects together in boxes. Grouping objects in this
way allows greater control of the panel layout. See
the section below on BOXES.

.SH CONTROLLING XTPANEL
The rest of this manual page describes
how to write xtpanel script files or run xtpanel from the command
line. If you just want to use it, and don't want to write script
files or learn the command line syntax, then run the automatic
script generator described above. The generator is also a good
way to learn about the script language, since it allows you to
view, edit, and test a script file as it is being built.

.SH SCRIPT VS. COMMAND LINE
The typical xtpanel script contains lines of the form:

.br
object_type={ parameter1=value1 parameter2=value2 ... }

.br
This format is very flexible; the parameters can be supplied in 
any order, or omitted and defaults will be provided. Line breaks can 
occur anywhere.
.PP
From the command line, all objects and all their parameters must
be specified on the same line in a precise order:

.br
-object_type value1 value2 value3... -object_type value1 ...

.PP
Some parameters can be omitted; the "-" on the beginning
of the next object tells xtpanel to stop reading parameters
for one object and begin the next. However, in order to 
specify a particular parameter, all those up to it in the
sequence must be specified. (For instance, in the case above,
to specify value3 for the first object, one must also specify
value1 and value2, while in a script they could be omitted and left to
default.)
.PP
For these reasons, and because the command line format
(where the entire panel is specified on a single line)
is more difficult to read, it is recommended that a script file be
used for all but the smallest examples. The following section
describes the objects in greater detail, along with the
script language syntax. If you wish instead to use the
command line interface, see the COMMAND LINE SYNTAX
section below.
.PP
Note that scripts and the command line interface can be mixed, and multiple
script files can be read using the "-file" option (see GENERAL COMMAND 
LINE OPTIONS, below.) So the following is a valid xtpanel command:
.br
xtpanel <script1 -file script2 -quit.
 
.SH DESCRIPTION OF OBJECTS AND SCRIPT SYNTAX
Here is a more detailed description of the objects,
the parameters relevant to each, and the syntax for
building these objects in a script file.

The general format for specifying an object in a script file is:

.br
object_type={ parameter=value ... }

Note that no spaces are allowed between
the object_type and the "{".

Each "value" can take one of four forms:
A single word, a string enclosed in single quotes, string enclosed in
double quotes, a system command enclosed in backquotes. See the section
"SCRIPT SYNTAX DETAILS" for more information on the syntax. 

.PP
There are four parameters that many objects have in common, these are:
name, label, action and value.

\fIname\fP is the name of the object. A name must consist of 
a single word containing only alphanumeric characters. The name
serves two purposes, it can be referred to by other objects who wish
to obtain the string representation of the object and it can be used
in modifying the appearance of an object using the X-toolkit resource
mechanism. 

\fIlabel\fP is the label that appears on the object. By default it
is the set to the name. It will appear in an "appropriate" place
which depends on the object type.

\fIvalue\fP is the initial string value associate with the object.
If the object is modified this string value will change. It defaults to
be the same as label.

\fIaction\fP is an action that occurs when the button is pressed.
Defaults to "NONE", which means that the button simply maintains a
string, containing its value, for use by other objects.  Other actions
are PRINT (print string to standard output), SYSTEM (execute a
command), STRING (reformat the internal representation of the object's
value, where the string can contain more than just the object's value)
, ASSIGN (set another object's value to a given string) and QUIT (quit xtpanel). See the section below on ACTIONS for more
details. If more than one action is present the actions will be performed 
in the order that they are specified.


.IP \fImessage\fP 3
A message displays a single line of text on a panel.
Messages are used to give short instructions or bits of
information to the user. The script syntax for a message is:

.br
message={  value=.... name=.... }

The most important variable in a message object is the \fIvalue\fP. 
The value is the text that is displayed on the screen. 
The \fIname\fP is relevant for tailoring the appearance of
this message object using resources or assigning new values to the
message. If a new value is assigned to the message the text will change
to reflect the new value.

.br
example:
.br
message={ value=" hello world, I am a message object " }

.IP \fItext\fP 3
A text object displays any number of lines of text in
a multi-line scrollable region.

.br
text={ value=....  name=.... width=.... height=.... }

The \fIvalue\fP is the text to be displayed on the screen.
Newlines in the value will cause the text to start a new line.
The \fIname\fP is relevant for tailoring the appearance of
this text object using resources  or assigning new values to the
message. If a new value is assigned to the text the text will change
to reflect the new value.
\fIwidth\fP and \fIheight\fP and the dimensions of the text area in
pixels. Scrollbars are automatically added when needed.

.br
examples:
.br
text={ value="I am a multiline \\n text object \\n with three lines" }
.br
text={ value=`cat README` }

.IP \fIbutton\fP 3
Button is the first of the interactive objects. Pressing
the button will cause a specified action to take place.

.br
button={ label=... value=... name=... action=... }

\fIname\fP defaults to "button1", "button2" etc.
\fIlabel\fP is the text  that appears on the button. 
\fIvalue\fP is the string value associated with the button.
\fIaction\fP is an action that occurs when the button is pressed. 

Assigning a new value to a button does not change the appearance of the
button but it will change the value used in an action.

.br
example:
.br
button={ label="Press me" action="PRINT Aargh! I was pressed" }

.IP \fIdialog\fP 3
A dialog displays an editable text field. Syntax:

.br
dialog={ label=... value=... name=... action=... }

\fIname\fP  defaults to "dialog1", "dialog2" etc.
\fIlabel\fP appears above the text field.
\fIvalue\fP is the text that initially appears in the text field.
A value of "" means that the text field will initially be blank.
\fIaction\fP: For action types SYSTEM and PRINT, an "ok" button is added to the
panel, and the dialog object is activated when this button is
pressed. For action type STRING the action occurs whenever the
user moves out of the text field.

Assigning a new value to a dialog changes the displayed string to the new value.

.br
example:
.br
dialog={ label="Filename to edit" value="" action="xterm -e vi $val" }

.IP \fIslider\fP 3
A slider lets the user choose a value from a range of integer
or floating point values. Syntax:

.br
slider={ label=... value=... name=... action=... min=... max=... 
format=... width=... height=... }

A slider object has a label, a slider and a text field that
displays the current slider value. If the action type is SYSTEM or PRINT there 
will also be an "OK" button to allow the user to trigger the 
action. 

\fIname\fP defaults to "slider1", "slider2" etc. 
\fIlabel\fP appears above the slider.
\fIvalue\fP is the starting value for the slider; defaults to the minimum.
\fIaction\fP: For action types SYSTEM and PRINT the action occurs when 
the "ok" button is pressed. For action type STRING the action occurs when 
the slider position changes.

Assigning a new value to a slider changes the slider position to match the
new value. If the new value string is not a number (as intepreted by the
routine atof() ) the slider will be set to zero.

\fImin\fP is the minimum value for the slider; defaults to 0. 
\fImax\fP is the maximum value for the slider; defaults to 1. 

\fIformat\fP is the format with which the slider label and its internal string 
will be printed. The slider value is stored internally as a floating point
number; the default value for format is %f, which prints the value
with five decimal places. You can specify a different format, according
to the format specification for the C programming language. To obtain
in integer-only slider, use a format of %.0f (the 0 indicates no digits
after the decimal point).

\fIwidth\fP and \fIheight\fP are the lengths of the major and minor
axes of the slider. By default, sliders are oriented horizontally.
This can be changed by overriding the orientation set in the resource
file.

.br
example
.br
slider={ label=Velocity min=1000 max=4000 value=2000 format=%4.0f }

.IP \fIchoice\fP 3
A choice object is a set of toggle buttons. Each button may
be set on or off, but only one button may be active at a time. Syntax:

.br
choice={ label=... value=... name=... action=... item=... itemlist=... }

The choice object consists of a text label and a set of buttons.
The value of the object on output is set to the value associated with 
the active button.

\fIname\fP  defaults to "choice1", "choice2" etc.
\fIlabel\fP  appears adjacent to the buttons.
\fIvalue\fP is the initial value associated with the 
choice. It must match the value of one of the buttons, or by default
it is set to the value of the first button.
\fIaction\fP is an action that occurs when a button is pressed. 

Assigning a new value to a choice changes the choice to match the new
value. If the new value does not match any item's value the choice will be
unchanged.

\fIitem\fP and \fIitemlist\fP are used to describe the buttons
contained in a choice. You can either specify buttons one at a
time with item, or in groups with itemlist. See the detailed
descriptions of item and itemlist below. There is no limit on
the number of items or itemlists used in a choice object.

.br
example:
.nf
choice={ label="english colors" action="PRINT use $val " 
		item={ label=red } item={ label=green } item={ label=blue }
            }
.fi

.IP \fImenubutton\fP 3
A button with a pulldown menu. Syntax:

menubutton={ label=... value=... name=... action=... item=... itemlist=... }

\fIname\fP  defaults to "menubutton1", "menubutton2" etc.  
\fIlabel\fP  appears on the button.
\fIvalue\fP is the initial value associated with the menu. 
It must match the value of one of the menu items, or it
defaults to be the same as the value of the first menu item. 
\fIaction\fP  occurs when a menu item is selected. 

\fIitem\fP and \fIitemlist\fP are used to describe the options
contained in a menu. You can either specify buttons one at a
time with item, or in groups with itemlist. See the detailed
descriptions of item and itemlist below. There is no limit on
the number of items or itemlists used in a menubutton object.

Assigning a new value to a menubutton changes the menubutton to match the new
value. If the new value does not match any item's value the menubutton will be
unchanged.

.br
example
.nf
menubutton={ label="french color" action="PRINT utilisez $val " 
	item={ label=red value=rouge } 
        item={ label=green value=vert } 
        item={ label=blue value=bleu }
            }
.fi

.IP \fIlist\fP 3
A list of items; the user clicks on one of the items to select it.
Syntax:

.br
list={ label=... value=... name=... action=... item=... itemlist=... }

The list object has a text label and a list of items.

\fIname\fP  defaults to "list1", "list2" etc.
\fIlabel\fP appears adjacent to the list.
\fIvalue\fP is the initial value associated with the list. It must
match the value of one of the list items, or it defaults to be
the same as the value of the first list item.
\fIaction\fP occurs when an item is selected. 

\fIitem\fP and \fIitemlist\fP are used to describe the items
contained in a list. You can either specify items one at a
time with item, or in groups with itemlist. See the detailed
descriptions of item and itemlist below. There is no limit on
the number of items or itemlists used in a list object.

Assigning a new value to a list changes the list value to match the new
value. If the new value does not match any item's value the list will be
unchanged.

.br
example:
.nf
list={ label="german color" action="PRINT benutze $val " 
	item={ label=red value=rot } 
        item={ label=green value=gruen } 
        item={ label=blue value=blau }
            }
.fi


.IP \fIitem\fP 3
Item is used to specify a single item for a choice, menu or list.
Syntax:

.br
item={ label=... value=... }

\fIlabel\fP is the label that appears on the screen,
as the name of the button (for choice) or on the menu or list.
Defaults to "item1", "item2" etc.
\fIvalue\fP is the value that is set in the parent object when this
item is selected. Defaults to be the same as label.
Item is preferred over itemlist when the text displayed
on the screen for an item and that used for its value differ.

.br
example:
.br
item={ label=Two value=2 }

.IP \fIitemlist\fP 3
Itemlist is used to specify several items for a choice, menu or list.
Syntax:

.br
itemlist={ list=... separator=... }

\fIlist\fP is a single string containing a list of items. The string 
will be parsed to obtain the individual items. The label and value
of each item will be the same, set to the string taken from the list.
Thus itemlist is not appropriate when the text displayed on
the screen for an item (the label) and that used for the value 
are to differ.
\fIseparator\fP is a string of characters that is used to separate different 
items in the list string. Defaults to separator=" " (the blank character.)

.br
examples:
.nf
itemlist={ list="red white blue" } 
itemlist={ list=`ls -aF` separator=" \\n" }
.fi

.IP \fIvar\fP 3
Var is an object that has a value and no screen representation.

Syntax:
var={ name=... value=... }
\fIname\fP  defaults to "var1", "var2" etc.  
\fIvalue\fP is the value of the var. 


Variables can be used for adding arbitrary arguments on the command line. See
the command line syntax below. The values of var objects may be used
in the action of other objects so that an xtpanel's behaviour can be
modified without changing the script file. Also the value of a var may be changed by the ASSIGN action of another object. Thus a Var can be used to pass
information from one object to another.

.SH SCRIPT SYNTAX DETAILS
The general format for specifying an object in a script file is:

.br
object_type={ parameter=value ... }

Note that no spaces are allowed between
the object_type and the "{".

A line with an exclamation "!" in column one is treated as a comment line,
the rest of the line will be ignored.

Each "value" can take one of four forms:

.IP 1) 3 
A single word. 
.br
e.g. label=fred

.IP 2) 3 
zero or more words enclosed in single quotes 
.br
e.g. label='fred in quotes'
.br
The quotes are stripped before the value is stored. Two consecutive
single quotes within the quotes will produce a single quote in the
stored value. Any other type of quotes pass through unchanged.
.nf
e.g. ' ''fred'' is happy' is stored as -> 'fred' is happy<-
       '"fred" is happy' is stored as ->"fred" is happy<-
.fi

.IP 3) 3
zero or more words enclosed in double quotes
.br
e.g. label="fred in quotes"
.br
The quotes are stripped before the value is stored. Two consecutive
single quotes within the quotes will produce a single quote in the
stored value. Any other type of quotes pass through unchanged.
.nf
e.g. " ""fred"" is happy" is stored as -> "fred" is happy<-
     " ""fred"" is 'happy'" is stored as -> "fred" is 'happy'<-
.fi
Within either single or double quotes the following transformations are
applied to handle newlines:
.br
.nf
 newline                ->              newline
 backslash newline      ->              is removed 
 \\n                     ->              newline
.fi

.IP 4) 3
zero or more words enclosed in backquotes.
.br
e.g. label=`echo -n my name is fred`
.br
The value stored is the output produced by running the command using
the user's shell. 
.br
In this example the value stored is ->my name is fred<- 

Note the special case of a backquoted string within a quoted action.
See actions below.

.SH ACTIONS
AN action is a command performed when a user interface object has changed
its state. e.g. a button is pushed, a list item is chosen, a slider is
moved. If more than one action is pecified for an object then the separate
actions are performed in the order in which they are specified in the script
file.

There are six basic types of action NONE, QUIT, SYSTEM, PRINT, STRING and ASSIGN.

If no action is specified (or the action is specified as "NONE")
the action type is NONE. In this case an object 
will just maintain its string representation.  For dialogs, the string
is the contents of the text field; for sliders, the slider value;
for choice, menubutton and list objects, the value associated with
the selected item. When an object with action=NONE is modified, 
its string is kept up to date, but nothing else happens.

An action type of QUIT, specified as ACTION=QUIT, will cause the xtpanel
program to quit when the object is interacted with. The simple quit button
is written as: 
.br
button={ label=QUIT action=QUIT }

The final four action types (SYSTEM, PRINT, STRING and ASSIGN) are more 
complicated.  Each uses the format specified in the action command to 
generate a string.
If the action is SYSTEM, then that string is executed. If the action type
is PRINT then the string is printed to the standard output. If the action
is STRING then the string is stored as the internal string representation
of the object.

If the action type is ASSIGN the value of the other
object is set to the string. Additionaly the screen representation of the
object is updated to reflect the new value (if it makes sense to do so).
For example if the value of a dialog is updated the text field of the
dialog will contain the updated string. If a slider is updated the
slider thumb will be moved to the corresponding position.

The format specified can contain the names of objects preceded
by a dollar "$" sign. The value of the string associated with the object
is substitued in the generated string. The special symbol "$val" is used
to refer to the string associated with the current object. 
You should give an object a name 
if you intend to use its string in the action of another object.
A double
dollar sign "$$" is used to generate a single dollar in the generated
string. 

If a format contains a command enclosed in backquotes then the output
produced by running the command will be subsituted in the generated string.
The command will be run when the action takes place. i.e. if a backquoted
command is present in the action for a button then the command will be run
each time the button is pressed. Note that the evaluation of the command takes 
place after the substitution of object values, thus the backquoted command
evaluated at action time may contain an evaluated object value.

The ASSIGN action is special because the word immediately following the
word ASSIGN (separated by blanks) is the name of an object that will have
its value set to the formatted string. The format is thus assumed to start
at the second word after ASSIGN.

An action type of PRINT is used for any action command that begins with
PRINT (It must be in upper case and start at the first character of the action
string). An action type of STRING is used for any command that begins with
STRING. An action type of ASSIGN is used for any command that begins with
the word ASSIGN. An action type of SYSTEM is used for any command that doesn't
begin with QUIT, STRING, PRINT or ASSIGN or if it begins with SYSTEM.


Following are two examples of using actions.

Here is a choice object that uses its value as a parameter
for an imaginary system command, showcolor:

.nf
choice={ label=colors value="255 0 0" action="showcolor -rgb $val"
         item={ label=red value="255 0 0" }
         item={ label=green value="0 255 0" }
         item={ label=blue value="0 0 255" }
       }
.fi

In this next example, the list item has no action specified. Actions
default to type NONE; the list will maintain a string containing
the value of the selected list item, but will do nothing more.
Here a separate button is used to do something with the list's
output:

.nf
message={ label="press button to find out which item is selected" }
list={ label=numbers name=listout
         itemlist={ list="1 2 3"
       }
button={ label="press for answer" action="PRINT list selection is $listout" }
.fi

In this example the assign action is used to reset the value of a dialog
to a known string (fred). The reset button assigns the string to the dialog.
The dialog itself has two actions, the first prints the value of the
text field and the second action quits xtpanel.

.nf
dialog={ label=dialog value="fred" 
         action="PRINT I am $val" 
         action=QUIT 
       }

button={ label=RESET action="ASSIGN dialog fred" }
.fi


In the final example the user can select a file from all the ".ps" files
in the current directory. The file is then viewed with the ghostview program:

.nf
button={ label=QUIT action=QUIT }
list={ label="Choose a file" action="ghostview $val" 
         itemlist={ list=`echo *.ps`  }
       }
.fi

.SH BOXES
Several objects are provided to manage the appearance
of the panel. These box objects group other objects
into boxes that are oriented either vertically or
horizontally. In a vertically oriented box, 
the objects are arranged in a single column, and then
a box is drawn around them. A vertically oriented box
(vbox) is specified as follows:

.nf
vbox={ name=
object_type={ parameter=value ... }
object_type={ parameter=value ... }
}
.fi

All of the objects bounded by the starting and ending braces
of a box will be grouped together in the box. In addition
to vbox, there is hbox, which is oriented horizontally,
and vpane and hpane, where the objects within the box are
separated by movable partitions (these use the Athena
paned widget). There is also box and pane; these default
to vbox and vpane, but could be overridden from a resource
file.

Boxes can be nested. In this way, fairly precise control
over a panel's layout is obtained.

Box objects have only a single parameter, \fIname\fB.
Two special names are recognized by the resource
file; boxes with name=\fInoborder\fB will have no
border drawn around them. If you use boxes extensively
to arrange objects on the panel, using noborder can help
avoid the tunnel-like appearance of multiple nested boxes.
Also, one of the examples makes use of a special
box name \fIsqueezebox\fB.
This name triggers definitions in
the resource file that "squeeze out" the annotation
of sliders, choices, and buttons that are grouped together
in such a box. When a number of sliders are squeezed together
in this way, the result is a seemingly new object that lets
the user manipulate the data samples of a function. See the
"sliderbox" examples in the panel brought up doing "run_demos"
in the xtpanel source directory.

.SH COMMAND LINE INTERFACE
On the command line, objects are specified in the following
format:

xtpanel -object_type value value ... -object_type value...

The values must be specified in a prescribed order, as described
below for each object type. You can specify as many of the
values for a given object as you wish; the "-" on the object
type is the signal to xtpanel to stop reading parameters for
one object and begin the next. But in
order to specify a value for one parameter, you MUST specify values all those
that precede it, in exactly the order specified here.

The values for each object are described in the section
above named DESCRIPTION OF OBJECTS AND SCRIPT SYNTAX.
Here we simply list them in the order that they
must be specified from the command line.

.nf
\-message    [value]
\-text       [value width height]
\-button     [label action name value]
\-dialog     [label action name value]
\-slider     [label action name value min max format width height]
\-choice     [label action name value numchoice label value ...]
\-menubutton [label action name value numchoice label value ...]
\-list       [label action name value numchoice label value ...]
\-var        [name value]
\-quit	     
.fi

For the multiple-choice objects (choice, menubutton, and list),
you must specify a label (which gets displayed on the screen)
and a value (used on output) for each item, and you must
precede these by the number of items in the choice,
menubutton, or list (which is not required in a script).
There is no analog
to the script "itemlist" object, which lets you specify only
one string for each item instead of two.

Note that the box objects described above (see BOXES),
used to group objects into horizontally or vertically
oriented boxes, are not available from the command line.

.SH COMMAND LINE EXAMPLES
The following examples illustrate the use of xtpanel from the
command line:

This example contains a quit button and a message:

.nf
xtpanel -quit -message "this is a message"
.fi

This example contains a choice:

.nf
xtpanel -choice "this is a choice" 'PRINT choice is $val' name 1 
3 one 1 two 2 three 3  
.fi

This example contains a slider and a button that outputs the slider's value:

.nf
xtpanel -quit -slider "this is a slider" 'PRINT slider value is $val' 
name 5 0 10 "%.0f" 100 20 -button "press me" 'PRINT slider value is $name'
.fi

.SH GENERAL COMMAND LINE OPTIONS
.TP
.B \-file filename
Read in the script file "filename". Xtpanel also looks for
a script file on stdin. The filename specified in this way is searched
for in a number of possible directories.
If the environment variable "XTPANEL_PATH" is set it is assumed to be
a colon separated list of directories to be searched. If the file is not found
in these directories the program will search a directory called .xtpanel in
the users home directory and then the system xtpanel directory.

If the environment variable is not
set the program will search the current directory, followed by ~/.xtpanel
followed by the system xtpanel directory.

The system directory is specified in the Makefile used to compile the
xtpanel program. At compilation time on this system it was set to
/usr/local/lib/X11/xtpanel.

.TP
.B \-cpp [cpp_args]
If the -cpp flag is specified then all files read using the "-file" flag
will be passed though the C-preprocessor before being parsed. The preprocessor
will be invoked using any command line argumnts that look like they might be
C-preprocessor arguments. Currently this is interpreted as being any argument
that starts with "-I" or "-D". Note the standard input is never passed through
cpp. If you wish to to this you should pipe the output of cpp into xtpanel
yourself.

This option can be very usesful in designing system wide xtpanel scripts
where a few key words may be changed at each invocation. These words may
be redefined with "-Doldname=newname". The -cpp option can also be used to
define macros for repeated parts of script files or even including prebuilt
pieces of script files from elsewhere. The following example illustrates
some of these possibilities.

.nf
#ifndef NAME
#define NAME "default name"
#endif

#define mkslid(VAL) slider={ label="" min=0 max=100 value=VAL width=300 
height=25 format="%.0f" action="STRING $val" }

label={ value=NAME }

mkslid(0)
mkslid(10)
mkslid(20)
.fi

.TP
.B \-help
Invokes a series of xtpanel scripts that present information
about xtpanel, mostly taken from this manual page, in an
interactive, menu-driven form.

.TP
.B \-tty
Read a script from the terminal. Generally not recommended;
it is better to save the script in a file first. If this option
is not set the program will not accept input from standard input if
it is a terminal. You can redirect standard input and pipe data to
xtpanel without setting this option.

.SH RESOURCES
All widgets are constructed using the "name" parameter of the object.
The X-toolkit resource mechanism can be used to control the appearance
of an object based on either its class or its name.
The xtpanel objects are constructed from Xaw widgets as follows:

.IP message 10 
is a Label widget
.IP text 10
is a Text widget
.IP button 10
is a Command widget
.IP dialog 10
is a Dialog widget
.IP scrollbar 10
is a Scrollbar widget.
.IP slider 10
is a Box containing two Labels and a Scrollbar.
.IP choice 10
is a Box containing a Label and a number of Toggles.
.IP menubutton 10
is a MenuButton. Attached to it is a SimpleMenu, with a
number of SmeBSB menu entries.
.IP list 10
is a Box containing a Label and a List.

If I have the following xtpanel script file:

button={ label=QUIT action=QUIT }

box={ name=bigfont
      button={ label=fred action="PRINT fred" }
      button={ label=joe name=curs action="PRINT joe" }
}

and the following resources:

XTpanel*Command.Font: fixed
XTpanel*bigfont*Command.Font: 8x16
XTpanel*bigfont*curs.Font: cursor

Then the quit button will use the "fixed" font, fred will use "8x16" and
joe will use "cursor" (and thus be unreadable).

.SH COPYRIGHT
Although xtpanel is not in the public domain, its copyright is not
very restrictive. Here is the official xtpanel copyright notice (the one
that all the source files tell you about):
.PP
Copyright 1992 the Board of Trustees of the Leland Stanford Junior
University.  All Rights Reserved.  Permission is hereby given
to use, copy, modify, and distribute this software provided
that (1) copyright and proprietary notices are retained in
each copy, (2) any files which are modified are identified as such,
and (3) you do not copy or distribute the software for payment or
for commercial use without prior written consent from Stanford.
STANFORD MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND
concerning this software or its use.

.SH BUGS
Probably many. Please send bug reports, suggestions,
interesting xtpanel scripts, code to support new widgets, etc.
to the authors.


.SH AUTHORS
Steve Cole (steve@sep.stanford.edu)
.br
Dave Nichols (dave@sep.stanford.edu)
.br
Stanford Exploration Project, Department of Geophysics
.br
Stanford University, Stanford, CA, 94305-2215
